register_files

Function register_files 

pub fn register_files(fds: &[RawFd]) -> Result<()>
Register file descriptors for fixed-file operations with the current runtime’s io_uring instance.

This only works on io_uring driver. It will return an Unsupported error on other drivers.

Panics

This method doesn’t create runtime. It tries to obtain the current runtime by Runtime::with_current.