spawn_at

Function spawn_at 

pub fn spawn_at<F: Future + 'static>(
    future: F,
    meta: SpawnMeta,
) -> JoinHandle<F::Output> 
Spawns a new asynchronous task, attributing it to meta instead of to the caller.

See Runtime::spawn_at for what meta is good for.

Panics

This method doesn’t create runtime. It tries to obtain the current runtime by Runtime::with_current.