submit_multi

Function submit_multi 

pub fn submit_multi<T: OpCode + 'static>(op: T) -> SubmitMulti<T>
Submit a multishot operation to the current runtime, and return a stream for it.

Panics

This method doesn’t create runtime and will panic if it’s not within a runtime. It tries to obtain the current runtime with Runtime::with_current.