CancelToken

Struct CancelToken 

pub struct CancelToken(/* private fields */);
A token that can be used to cancel multiple operations at once.

When CancelToken::cancel is called, all operations that have been registered with this token will be cancelled.

It is also possible to use CancelToken::wait to wait until the token is cancelled, which can be useful for implementing timeouts or other cancellation-based logic.

To associate a future with this cancel token, use the with_cancel combinator from the FutureExt trait.

Implementations

Source

impl CancelToken

pub fn new() -> Self

Create a new cancel token.

Panics

CancelToken can only be created within compio runtime environment. This will panic without a runtime.

pub fn cancel(self)

Cancel all operations registered with this token.

pub fn is_cancelled(&self) -> bool

Check if this token has been cancelled.

pub fn register<T: OpCode>(&self, key: &Key<T>)

Register an operation with this token.

If the token has already been cancelled, the operation will be cancelled immediately. Usually this method should not be used directly, but rather through the with_cancel combinator.

Multiple registrations of the same key does nothing, and the key will only be cancelled once.

pub fn wait(self) -> WaitFuture

Wait until this token is cancelled.

pub async fn current() -> Option<Self>

Try to get the current cancel token associated with the future.

This is done by checking if the current context has a cancel token associated with it.