Runtime

Struct Runtime 

pub struct Runtime(/* private fields */);
The async runtime of compio.

It is a thread-local runtime, meaning it cannot be sent to other threads.

Implementations

Source

impl Runtime

pub fn new() -> Result<Self>

Create Runtime with default config.

pub fn builder() -> RuntimeBuilder

Create a builder for Runtime.

pub fn driver_type(&self) -> DriverType

The current driver type.

pub fn try_with_current<T, F: FnOnce(&Self) -> T>(f: F) -> Result<T, F>

Try to perform a function on the current runtime, and if no runtime is running, return the function back.

pub fn with_current<T, F: FnOnce(&Self) -> T>(f: F) -> T

Perform a function on the current runtime.

Panics

This method will panic if there is no running Runtime.

pub fn try_current() -> Option<Self>

Try to get the current runtime, and if no runtime is running, return None.

pub fn current() -> Self

Get the current runtime.

Panics

This method will panic if there is no running Runtime.

pub fn enter<T, F: FnOnce() -> T>(&self, f: F) -> T

Set this runtime as current runtime, and perform a function in the current scope.

pub fn run(&self) -> bool

Low level API to control the runtime.

Run the scheduled tasks.

The return value indicates whether there are still tasks in the queue.

pub fn waker(&self) -> Waker

Low level API to control the runtime.

Create a waker that always notifies the runtime when woken.

pub fn opt_waker(&self) -> Arc<OptWaker>

Low level API to control the runtime.

Create an optimized waker that only notifies the runtime when woken from another thread, or when notify-always is enabled.

pub fn block_on<F: Future>(&self, future: F) -> F::Output

Block on the future till it completes.

pub fn spawn<F: Future + 'static>(&self, future: F) -> JoinHandle<F::Output>

Spawns a new asynchronous task, returning a JoinHandle for it.

Spawning a task enables the task to execute concurrently to other tasks. There is no guarantee that a spawned task will execute to completion.

pub fn spawn_blocking<T: Send + 'static>( &self, f: impl FnOnce() -> T + Send + 'static, ) -> JoinHandle<T>

Spawns a blocking task in a new thread, and wait for it.

The task will not be cancelled even if the future is dropped.

pub fn attach(&self, fd: RawFd) -> Result<()>

Attach a raw file descriptor/handle/socket to the runtime.

You only need this when authoring your own high-level APIs. High-level resources in this crate are attached automatically.

pub fn submit<T: OpCode + 'static>(&self, op: T) -> Submit<T>

Submit an operation to the runtime.

You only need this when authoring your own OpCode.

pub fn submit_multi<T: OpCode + 'static>(&self, op: T) -> SubmitMulti<T>

Submit a multishot operation to the runtime.

You only need this when authoring your own OpCode.

pub fn current_timeout(&self) -> Option<Duration>

Low level API to control the runtime.

Get the timeout value to be passed to Proactor::poll.

pub fn poll(&self)

Low level API to control the runtime.

Poll the inner proactor. It is equal to calling Runtime::poll_with with Runtime::current_timeout.

pub fn poll_with(&self, timeout: Option<Duration>)

Low level API to control the runtime.

Poll the inner proactor with a custom timeout.

pub fn buffer_pool(&self) -> Result<BufferPool>

Get buffer pool of the runtime.

This will lazily initialize the pool at the first time it’s accessed, and future access to the pool will be cheap and infallible.

pub fn register_files(&self, fds: &[RawFd]) -> Result<()>

Register file descriptors for fixed-file operations.

This is only supported on io-uring driver, and will return an Unsupported io error on all other drivers.

pub fn unregister_files(&self) -> Result<()>

Unregister previously registered file descriptors.

This is only supported on io-uring driver, and will return an Unsupported io error on all other drivers.

pub fn register_personality(&self) -> Result<u16>

Register the personality for the runtime.

This is only supported on io-uring driver, and will return an Unsupported io error on all other drivers.

The returned personality can be used with FutureExt::with_personality.

pub fn unregister_personality(&self, personality: u16) -> Result<()>

Unregister the given personality for the runtime.

This is only supported on io-uring driver, and will return an Unsupported io error on all other drivers.