pub struct WithCancel<F: ?Sized> { /* private fields */ }Expand description
A future with a CancelToken attached to it.
Created with FutureExt::with_cancel.
When the cancel token is triggered, this future will still be
polled until completion, only compio operations that registered its Key
to the cancel token will be cancelled. If you want a future that completes
with an error immediately when the cancel token is triggered, see WithCancelFailFast.
Implementations
Sourceimpl<F: ?Sized> WithCancel<F>
impl<F: ?Sized> WithCancel<F>
Sourcepub fn new(future: F, cancel: CancelToken) -> Selfwhere
F: Sized,
pub fn new(future: F, cancel: CancelToken) -> Selfwhere
F: Sized,
Create a new WithCancel future.
Sourceimpl<F> WithCancel<F>
impl<F> WithCancel<F>
Sourcepub fn fail_fast(self) -> WithCancelFailFast<F> ⓘ
pub fn fail_fast(self) -> WithCancelFailFast<F> ⓘ
Convert to a fail-fast version.
When the cancel token is triggered, the future will be notified and complete with an error without further polling the inner future.