pub struct PollFd<T: AsFd>(/* private fields */);Expand description
Providing functionalities to wait for readiness.
Implementations
Sourceimpl<T: AsFd + 'static> PollFd<T>
impl<T: AsFd + 'static> PollFd<T>
Sourcepub async fn accept_ready(&self) -> Result<()>
pub async fn accept_ready(&self) -> Result<()>
Wait for accept readiness, before calling accept, or after accept
returns WouldBlock.
Sourcepub async fn connect_ready(&self) -> Result<()>
pub async fn connect_ready(&self) -> Result<()>
Wait for connect readiness.
Sourcepub async fn read_ready(&self) -> Result<()>
pub async fn read_ready(&self) -> Result<()>
Wait for read readiness.
Sourcepub async fn write_ready(&self) -> Result<()>
pub async fn write_ready(&self) -> Result<()>
Wait for write readiness.
Sourcepub fn poll_accept_ready(&self, cx: &mut Context<'_>) -> Poll<Result<()>>
pub fn poll_accept_ready(&self, cx: &mut Context<'_>) -> Poll<Result<()>>
Poll for accept readiness.
Sourcepub fn poll_connect_ready(&self, cx: &mut Context<'_>) -> Poll<Result<()>>
pub fn poll_connect_ready(&self, cx: &mut Context<'_>) -> Poll<Result<()>>
Poll for connect readiness.
Sourcepub fn poll_read_ready(&self, cx: &mut Context<'_>) -> Poll<Result<()>>
pub fn poll_read_ready(&self, cx: &mut Context<'_>) -> Poll<Result<()>>
Poll for read readiness.
Sourcepub fn poll_write_ready(&self, cx: &mut Context<'_>) -> Poll<Result<()>>
pub fn poll_write_ready(&self, cx: &mut Context<'_>) -> Poll<Result<()>>
Poll for write readiness.
Sourcepub fn poll_accept_with<R>(
&self,
cx: &mut Context<'_>,
f: impl FnMut(&T) -> Result<R>,
) -> Poll<Result<R>>
pub fn poll_accept_with<R>( &self, cx: &mut Context<'_>, f: impl FnMut(&T) -> Result<R>, ) -> Poll<Result<R>>
Poll for accept readiness and call the provided function.
Sourceimpl<T: AsFd + 'static> PollFd<T>
impl<T: AsFd + 'static> PollFd<T>
Sourcepub fn poll_read(
&self,
cx: &mut Context<'_>,
buf: &mut [u8],
) -> Poll<Result<usize>>
pub fn poll_read( &self, cx: &mut Context<'_>, buf: &mut [u8], ) -> Poll<Result<usize>>
Poll for read readiness and read data.
Sourcepub fn poll_read_buf(
&self,
cx: &mut Context<'_>,
buf: BorrowedCursor<'_, u8>,
) -> Poll<Result<()>>
Available on crate feature read_buf only.
pub fn poll_read_buf( &self, cx: &mut Context<'_>, buf: BorrowedCursor<'_, u8>, ) -> Poll<Result<()>>
read_buf only.Poll for read readiness and read data into an uninitialized buffer.
Sourceimpl<T: AsFd + 'static> PollFd<T>
impl<T: AsFd + 'static> PollFd<T>
Sourcepub fn poll_write(
&self,
cx: &mut Context<'_>,
buf: &[u8],
) -> Poll<Result<usize>>
pub fn poll_write( &self, cx: &mut Context<'_>, buf: &[u8], ) -> Poll<Result<usize>>
Poll for write readiness and write data.
Sourcepub fn poll_write_vectored(
&self,
cx: &mut Context<'_>,
bufs: &[IoSlice<'_>],
) -> Poll<Result<usize>>
pub fn poll_write_vectored( &self, cx: &mut Context<'_>, bufs: &[IoSlice<'_>], ) -> Poll<Result<usize>>
Poll for write readiness and write data from a slice of buffers.
Whether this is more efficient than poll_write depends on the
source: it is a single writev for sockets and files, while other
sources may fall back to writing the first non-empty buffer.