PollFd

Struct PollFd 

pub struct PollFd<T: AsFd>(/* private fields */);
Providing functionalities to wait for readiness.

Implementations

Source

impl<T: AsFd> PollFd<T>

pub fn new(source: T) -> Result<Self>

Create PollFd without attaching the source.

Ready-based sources does not need to be attached.

pub fn from_shared_fd(inner: SharedFd<T>) -> Result<Self>

Create PollFd from a shared file descriptor.

Source

impl<T: AsFd + 'static> PollFd<T>

pub async fn accept_ready(&self) -> Result<()>

Wait for accept readiness, before calling accept, or after accept returns WouldBlock.

pub async fn connect_ready(&self) -> Result<()>

Wait for connect readiness.

pub async fn read_ready(&self) -> Result<()>

Wait for read readiness.

pub async fn write_ready(&self) -> Result<()>

Wait for write readiness.

pub fn poll_accept_ready(&self, cx: &mut Context<'_>) -> Poll<Result<()>>

Poll for accept readiness.

pub fn poll_connect_ready(&self, cx: &mut Context<'_>) -> Poll<Result<()>>

Poll for connect readiness.

pub fn poll_read_ready(&self, cx: &mut Context<'_>) -> Poll<Result<()>>

Poll for read readiness.

pub fn poll_write_ready(&self, cx: &mut Context<'_>) -> Poll<Result<()>>

Poll for write readiness.

pub fn poll_accept_with<R>( &self, cx: &mut Context<'_>, f: impl FnMut(&T) -> Result<R>, ) -> Poll<Result<R>>

Poll for accept readiness and call the provided function.

pub fn poll_read_with<R>( &self, cx: &mut Context<'_>, f: impl FnMut(&T) -> Result<R>, ) -> Poll<Result<R>>

Poll for read readiness and call the provided function.

pub fn poll_write_with<R>( &self, cx: &mut Context<'_>, f: impl FnMut(&T) -> Result<R>, ) -> Poll<Result<R>>

Poll for write readiness and call the provided function.

Source

impl<T: AsFd + 'static> PollFd<T>
where for<'a> &'a T: Read,

pub fn poll_read( &self, cx: &mut Context<'_>, buf: &mut [u8], ) -> Poll<Result<usize>>

Poll for read readiness and read data.

pub fn poll_read_buf( &self, cx: &mut Context<'_>, buf: BorrowedCursor<'_, u8>, ) -> Poll<Result<()>>

Available on crate feature read_buf only.

Poll for read readiness and read data into an uninitialized buffer.

Source

impl<T: AsFd + 'static> PollFd<T>
where for<'a> &'a T: Write,

pub fn poll_write( &self, cx: &mut Context<'_>, buf: &[u8], ) -> Poll<Result<usize>>

Poll for write readiness and write data.